import React, { Fragment } from 'react'
import { isEmpty, get, last } from 'lodash'
import styled from 'styled-components'
import {
  Text,
  RemoteOpener,
  ManuscriptHeader,
  ManuscriptAssignHE,
  ManuscriptMetadata,
  ManuscriptDetailsTop,
  ManuscriptEicDecision,
} from 'pubsweet-component-faraday-ui'

const eicDecisions = [
  { value: 'return-to-handling-editor', label: 'Return to Handling Editor' },
  { value: 'publish', label: 'Publish' },
  { value: 'reject', label: 'Reject' },
]

const messagesLabel = {
  'return-to-handling-editor': 'Comments for Handling Editor',
  publish: 'Comments for Author',
  reject: 'Comments for Author',
}

const ManuscriptLayout = ({
  history,
  assignHE,
  revokeHE,
  currentUser,
  getSignedUrl,
  editorInChief,
  handlingEditors,
  createRecommendation,
  hasResponseToReviewers,
  editorialRecommendations,
  journal = {},
  collection = {},
  fragment = {},
  permissions,
  isFetching,
  formValues,
}) => (
  <Root>
    {!isEmpty(collection) && !isEmpty(fragment) ? (
      <RemoteOpener>
        {(expanded, toggle) => (
          <Fragment>
            <ManuscriptDetailsTop
              collection={collection}
              currentUser={currentUser}
              fragment={fragment}
              getSignedUrl={getSignedUrl}
              history={history}
              {...permissions}
            />

            <ManuscriptHeader
              collection={collection}
              currentUser={currentUser}
              editorInChief={editorInChief}
              fragment={fragment}
              handlingEditors={handlingEditors}
              inviteHE={toggle}
              isFetching={isFetching.editorsFetching}
              journal={journal}
              resendInvitation={assignHE}
              revokeInvitation={revokeHE}
            />

            <ManuscriptMetadata
              currentUser={currentUser}
              fragment={fragment}
              getSignedUrl={getSignedUrl}
            />

            <ManuscriptAssignHE
              assignHE={assignHE}
              currentUser={currentUser}
              expanded={expanded}
              handlingEditors={handlingEditors}
              isFetching={isFetching.editorsFetching}
              toggle={toggle}
            />

            {permissions.canMakeDecision && (
              <ManuscriptEicDecision
                formValues={get(formValues, 'eicDecision')}
                isFetching={isFetching.recommendationsFetching}
                messagesLabel={messagesLabel}
                mt={2}
                options={
                  get(collection, 'status', 'submitted') === 'submitted'
                    ? [last(eicDecisions)]
                    : eicDecisions
                }
                submitDecision={createRecommendation}
              />
            )}
          </Fragment>
        )}
      </RemoteOpener>
    ) : (
      <Text>Loading...</Text>
    )}
  </Root>
)

export default ManuscriptLayout

// #region styles
const Root = styled.div`
  overflow-y: auto;
  min-height: 50vh;
`
// #endregion
